// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: feature.proto
// Protobuf C++ Version: 7.34.1

#include "feature.pb.h"

#include <algorithm>
#include <type_traits>
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/generated_message_tctable_impl.h"
#include "google/protobuf/internal_visibility.h"
#include "google/protobuf/extension_set.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/wire_format_lite.h"
#include "google/protobuf/descriptor.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/reflection_ops.h"
#include "google/protobuf/wire_format.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"
PROTOBUF_PRAGMA_INIT_SEG
namespace _pb = ::google::protobuf;
namespace _pbi = ::google::protobuf::internal;
namespace _fl = ::google::protobuf::internal::field_layout;
namespace rocal {
namespace tensorflow {

inline constexpr Int64List::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_FIELD
        value_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::rocal::tensorflow::Int64List,
            PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::Int64List, _impl_.value_)>()
        }
        #else
        value_ {}
        #endif
        ,
        _value_cached_byte_size_{0} {}

template <typename>
constexpr Int64List::Int64List(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Int64List_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct Int64ListDefaultTypeInternal {
  constexpr Int64ListDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~Int64ListDefaultTypeInternal() {}
  union {
    Int64List _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 Int64ListDefaultTypeInternal _Int64List_default_instance_;

inline constexpr FloatList::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_FIELD
        value_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::rocal::tensorflow::FloatList,
            PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::FloatList, _impl_.value_)>()
        }
        #else
        value_ {}
        #endif
     {}

template <typename>
constexpr FloatList::FloatList(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(FloatList_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct FloatListDefaultTypeInternal {
  constexpr FloatListDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~FloatListDefaultTypeInternal() {}
  union {
    FloatList _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 FloatListDefaultTypeInternal _FloatList_default_instance_;

inline constexpr BytesList::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
        value_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::rocal::tensorflow::BytesList,
            PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::BytesList, _impl_.value_)>()
        }
        #else  // !PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
        value_ {}
        #endif
     {}

template <typename>
constexpr BytesList::BytesList(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(BytesList_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct BytesListDefaultTypeInternal {
  constexpr BytesListDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~BytesListDefaultTypeInternal() {}
  union {
    BytesList _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 BytesListDefaultTypeInternal _BytesList_default_instance_;

inline constexpr Feature::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : kind_{},
        _cached_size_{0},
        _oneof_case_{} {}

template <typename>
constexpr Feature::Feature(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Feature_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct FeatureDefaultTypeInternal {
  constexpr FeatureDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~FeatureDefaultTypeInternal() {}
  union {
    Feature _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 FeatureDefaultTypeInternal _Feature_default_instance_;
template <typename>
constexpr Features_FeatureEntry_DoNotUse::Features_FeatureEntry_DoNotUse(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Features_FeatureEntry_DoNotUse::MapEntry(Features_FeatureEntry_DoNotUse_class_data_.base()){}
#else   // PROTOBUF_CUSTOM_VTABLE
    : Features_FeatureEntry_DoNotUse::MapEntry() {
}
#endif  // PROTOBUF_CUSTOM_VTABLE
struct Features_FeatureEntry_DoNotUseDefaultTypeInternal {
  constexpr Features_FeatureEntry_DoNotUseDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~Features_FeatureEntry_DoNotUseDefaultTypeInternal() {}
  union {
    Features_FeatureEntry_DoNotUse _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 Features_FeatureEntry_DoNotUseDefaultTypeInternal _Features_FeatureEntry_DoNotUse_default_instance_;

inline constexpr FeatureList::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
        feature_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::rocal::tensorflow::FeatureList,
            PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::FeatureList, _impl_.feature_)>()
        }
        #else  // !PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
        feature_ {}
        #endif
     {}

template <typename>
constexpr FeatureList::FeatureList(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(FeatureList_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct FeatureListDefaultTypeInternal {
  constexpr FeatureListDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~FeatureListDefaultTypeInternal() {}
  union {
    FeatureList _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 FeatureListDefaultTypeInternal _FeatureList_default_instance_;

inline constexpr Features::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_MAP_FIELD
        feature_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::rocal::tensorflow::Features,
            PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::Features, _impl_.feature_)>()
        }
        #else
        feature_ {}
        #endif
     {}

template <typename>
constexpr Features::Features(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Features_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct FeaturesDefaultTypeInternal {
  constexpr FeaturesDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~FeaturesDefaultTypeInternal() {}
  union {
    Features _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 FeaturesDefaultTypeInternal _Features_default_instance_;
template <typename>
constexpr FeatureLists_FeatureListEntry_DoNotUse::FeatureLists_FeatureListEntry_DoNotUse(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : FeatureLists_FeatureListEntry_DoNotUse::MapEntry(FeatureLists_FeatureListEntry_DoNotUse_class_data_.base()){}
#else   // PROTOBUF_CUSTOM_VTABLE
    : FeatureLists_FeatureListEntry_DoNotUse::MapEntry() {
}
#endif  // PROTOBUF_CUSTOM_VTABLE
struct FeatureLists_FeatureListEntry_DoNotUseDefaultTypeInternal {
  constexpr FeatureLists_FeatureListEntry_DoNotUseDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~FeatureLists_FeatureListEntry_DoNotUseDefaultTypeInternal() {}
  union {
    FeatureLists_FeatureListEntry_DoNotUse _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 FeatureLists_FeatureListEntry_DoNotUseDefaultTypeInternal _FeatureLists_FeatureListEntry_DoNotUse_default_instance_;

inline constexpr FeatureLists::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_MAP_FIELD
        feature_list_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::rocal::tensorflow::FeatureLists,
            PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::FeatureLists, _impl_.feature_list_)>()
        }
        #else
        feature_list_ {}
        #endif
     {}

template <typename>
constexpr FeatureLists::FeatureLists(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(FeatureLists_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct FeatureListsDefaultTypeInternal {
  constexpr FeatureListsDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~FeatureListsDefaultTypeInternal() {}
  union {
    FeatureLists _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 FeatureListsDefaultTypeInternal _FeatureLists_default_instance_;
}  // namespace tensorflow
}  // namespace rocal
static constexpr const ::_pb::EnumDescriptor* PROTOBUF_NONNULL* PROTOBUF_NULLABLE
    file_level_enum_descriptors_feature_2eproto = nullptr;
static constexpr const ::_pb::ServiceDescriptor* PROTOBUF_NONNULL* PROTOBUF_NULLABLE
    file_level_service_descriptors_feature_2eproto = nullptr;
const ::uint32_t
    TableStruct_feature_2eproto::offsets[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
        protodesc_cold) = {
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::BytesList, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::BytesList, _impl_.value_),
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::FloatList, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::FloatList, _impl_.value_),
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::Int64List, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::Int64List, _impl_.value_),
        0,
        0x004, // bitmap
        PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::Feature, _impl_._oneof_case_[0]),
        PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::Feature, _impl_.kind_),
        PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::Feature, _impl_.kind_),
        PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::Feature, _impl_.kind_),
        PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::Feature, _impl_.kind_),
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::Features_FeatureEntry_DoNotUse, _impl_._has_bits_),
        5, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::Features_FeatureEntry_DoNotUse, _impl_.key_),
        PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::Features_FeatureEntry_DoNotUse, _impl_.value_),
        0,
        1,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::Features, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::Features, _impl_.feature_),
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::FeatureList, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::FeatureList, _impl_.feature_),
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::FeatureLists_FeatureListEntry_DoNotUse, _impl_._has_bits_),
        5, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::FeatureLists_FeatureListEntry_DoNotUse, _impl_.key_),
        PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::FeatureLists_FeatureListEntry_DoNotUse, _impl_.value_),
        0,
        1,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::FeatureLists, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::FeatureLists, _impl_.feature_list_),
        0,
};

static const ::_pbi::MigrationSchema
    schemas[] ABSL_ATTRIBUTE_SECTION_VARIABLE(protodesc_cold) = {
        {0, sizeof(::rocal::tensorflow::BytesList)},
        {5, sizeof(::rocal::tensorflow::FloatList)},
        {10, sizeof(::rocal::tensorflow::Int64List)},
        {15, sizeof(::rocal::tensorflow::Feature)},
        {21, sizeof(::rocal::tensorflow::Features_FeatureEntry_DoNotUse)},
        {28, sizeof(::rocal::tensorflow::Features)},
        {33, sizeof(::rocal::tensorflow::FeatureList)},
        {38, sizeof(::rocal::tensorflow::FeatureLists_FeatureListEntry_DoNotUse)},
        {45, sizeof(::rocal::tensorflow::FeatureLists)},
};
static const ::_pb::Message* PROTOBUF_NONNULL const file_default_instances[] = {
    &::rocal::tensorflow::_BytesList_default_instance_._instance,
    &::rocal::tensorflow::_FloatList_default_instance_._instance,
    &::rocal::tensorflow::_Int64List_default_instance_._instance,
    &::rocal::tensorflow::_Feature_default_instance_._instance,
    &::rocal::tensorflow::_Features_FeatureEntry_DoNotUse_default_instance_._instance,
    &::rocal::tensorflow::_Features_default_instance_._instance,
    &::rocal::tensorflow::_FeatureList_default_instance_._instance,
    &::rocal::tensorflow::_FeatureLists_FeatureListEntry_DoNotUse_default_instance_._instance,
    &::rocal::tensorflow::_FeatureLists_default_instance_._instance,
};
const char descriptor_table_protodef_feature_2eproto[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
    protodesc_cold) = {
    "\n\rfeature.proto\022\020rocal.tensorflow\"\032\n\tByt"
    "esList\022\r\n\005value\030\001 \003(\014\"\036\n\tFloatList\022\021\n\005va"
    "lue\030\001 \003(\002B\002\020\001\"\036\n\tInt64List\022\021\n\005value\030\001 \003("
    "\003B\002\020\001\"\252\001\n\007Feature\0221\n\nbytes_list\030\001 \001(\0132\033."
    "rocal.tensorflow.BytesListH\000\0221\n\nfloat_li"
    "st\030\002 \001(\0132\033.rocal.tensorflow.FloatListH\000\022"
    "1\n\nint64_list\030\003 \001(\0132\033.rocal.tensorflow.I"
    "nt64ListH\000B\006\n\004kind\"\217\001\n\010Features\0228\n\007featu"
    "re\030\001 \003(\0132\'.rocal.tensorflow.Features.Fea"
    "tureEntry\032I\n\014FeatureEntry\022\013\n\003key\030\001 \001(\t\022("
    "\n\005value\030\002 \001(\0132\031.rocal.tensorflow.Feature"
    ":\0028\001\"9\n\013FeatureList\022*\n\007feature\030\001 \003(\0132\031.r"
    "ocal.tensorflow.Feature\"\250\001\n\014FeatureLists"
    "\022E\n\014feature_list\030\001 \003(\0132/.rocal.tensorflo"
    "w.FeatureLists.FeatureListEntry\032Q\n\020Featu"
    "reListEntry\022\013\n\003key\030\001 \001(\t\022,\n\005value\030\002 \001(\0132"
    "\035.rocal.tensorflow.FeatureList:\0028\001B\201\001\n\026o"
    "rg.tensorflow.exampleB\rFeatureProtosP\001ZS"
    "github.com/tensorflow/tensorflow/tensorf"
    "low/go/core/example/example_protos_go_pr"
    "oto\370\001\001b\006proto3"
};
static ::absl::once_flag descriptor_table_feature_2eproto_once;
PROTOBUF_CONSTINIT const ::_pbi::DescriptorTable descriptor_table_feature_2eproto = {
    false,
    false,
    814,
    descriptor_table_protodef_feature_2eproto,
    "feature.proto",
    &descriptor_table_feature_2eproto_once,
    nullptr,
    0,
    9,
    schemas,
    file_default_instances,
    TableStruct_feature_2eproto::offsets,
    file_level_enum_descriptors_feature_2eproto,
    file_level_service_descriptors_feature_2eproto,
};
namespace rocal {
namespace tensorflow {
// ===================================================================

class BytesList::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<BytesList>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(BytesList, _impl_._has_bits_);
};

BytesList::BytesList(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, BytesList_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:rocal.tensorflow.BytesList)
}
PROTOBUF_NDEBUG_INLINE BytesList::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::rocal::tensorflow::BytesList& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
        value_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::rocal::tensorflow::BytesList,
            PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::BytesList, _impl_.value_)>()
        , from.value_}
        #else
        value_ { visibility, arena, from.value_ }
        #endif
     {}

BytesList::BytesList(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const BytesList& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, BytesList_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  BytesList* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:rocal.tensorflow.BytesList)
}
PROTOBUF_NDEBUG_INLINE BytesList::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
        value_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::rocal::tensorflow::BytesList,
            PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::BytesList, _impl_.value_)>()
        }
        #else
        value_ { visibility, arena }
        #endif
     {}

inline void BytesList::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
BytesList::~BytesList() {
  // @@protoc_insertion_point(destructor:rocal.tensorflow.BytesList)
  SharedDtor(*this);
}
inline void BytesList::SharedDtor(MessageLite& self) {
  BytesList& this_ = static_cast<BytesList&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL BytesList::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) BytesList(arena);
}
#ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
constexpr auto BytesList::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(BytesList),
                                            alignof(BytesList));
}
#else  // !PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
constexpr auto BytesList::InternalNewImpl_() {
  constexpr auto arena_bits = ::google::protobuf::internal::EncodePlacementArenaOffsets({
      PROTOBUF_FIELD_OFFSET(BytesList, _impl_.value_) +
          decltype(BytesList::_impl_.value_)::
              InternalGetArenaOffset(
                  ::google::protobuf::Message::internal_visibility()),
  });
  if (arena_bits.has_value()) {
    return ::google::protobuf::internal::MessageCreator::ZeroInit(
        sizeof(BytesList), alignof(BytesList), *arena_bits);
  } else {
    return ::google::protobuf::internal::MessageCreator(&BytesList::PlacementNew_,
                                 sizeof(BytesList),
                                 alignof(BytesList));
  }
}
#endif
constexpr auto BytesList::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_BytesList_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &BytesList::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<BytesList>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &BytesList::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<BytesList>(), &BytesList::ByteSizeLong,
              &BytesList::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(BytesList, _impl_._cached_size_),
          false,
      },
      &BytesList::kDescriptorMethods,
      &descriptor_table_feature_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull BytesList_class_data_ =
        BytesList::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
BytesList::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&BytesList_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(BytesList_class_data_.tc_table);
  return BytesList_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<0, 1, 0, 0, 2>
BytesList::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(BytesList, _impl_._has_bits_),
    0, // no _extensions_
    1, 0,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967294,  // skipmap
    offsetof(decltype(_table_), field_entries),
    1,  // num_field_entries
    0,  // num_aux_entries
    offsetof(decltype(_table_), field_names),  // no aux_entries
    BytesList_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::rocal::tensorflow::BytesList>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    // repeated bytes value = 1;
    {::_pbi::TcParser::FastBR1,
     {10, 0, 0,
      PROTOBUF_FIELD_OFFSET(BytesList, _impl_.value_)}},
  }}, {{
    65535, 65535
  }}, {{
    // repeated bytes value = 1;
    {PROTOBUF_FIELD_OFFSET(BytesList, _impl_.value_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kBytes | ::_fl::kRepSString)},
  }},
  // no aux_entries
  {{
  }},
};
PROTOBUF_NOINLINE void BytesList::Clear() {
// @@protoc_insertion_point(message_clear_start:rocal.tensorflow.BytesList)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
    _impl_.value_.Clear();
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL BytesList::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const BytesList& this_ = static_cast<const BytesList&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL BytesList::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const BytesList& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:rocal.tensorflow.BytesList)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // repeated bytes value = 1;
  if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
    for (int i = 0, n = this_._internal_value_size(); i < n; ++i) {
      const auto& s = this_._internal_value().Get(i);
      target = stream->WriteBytes(1, s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:rocal.tensorflow.BytesList)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t BytesList::ByteSizeLong(const MessageLite& base) {
  const BytesList& this_ = static_cast<const BytesList&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t BytesList::ByteSizeLong() const {
  const BytesList& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:rocal.tensorflow.BytesList)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
   {
    // repeated bytes value = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
      total_size +=
          1 * ::google::protobuf::internal::FromIntSize(this_._internal_value().size());
      for (int i = 0, n = this_._internal_value().size(); i < n; ++i) {
        total_size += ::google::protobuf::internal::WireFormatLite::BytesSize(
            this_._internal_value().Get(i));
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void BytesList::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<BytesList*>(&to_msg);
  auto& from = static_cast<const BytesList&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:rocal.tensorflow.BytesList)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
    _this->_internal_mutable_value()->InternalMergeFromWithArena(
        ::google::protobuf::MessageLite::internal_visibility(), arena,
        from._internal_value());
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void BytesList::CopyFrom(const BytesList& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:rocal.tensorflow.BytesList)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void BytesList::InternalSwap(BytesList* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.value_.InternalSwap(&other->_impl_.value_);
}

::google::protobuf::Metadata BytesList::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class FloatList::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<FloatList>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(FloatList, _impl_._has_bits_);
};

FloatList::FloatList(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, FloatList_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:rocal.tensorflow.FloatList)
}
PROTOBUF_NDEBUG_INLINE FloatList::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::rocal::tensorflow::FloatList& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_FIELD
        value_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::rocal::tensorflow::FloatList,
            PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::FloatList, _impl_.value_)>()
        , from.value_}
        #else
        value_ { visibility, arena, from.value_ }
        #endif
     {}

FloatList::FloatList(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const FloatList& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, FloatList_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  FloatList* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:rocal.tensorflow.FloatList)
}
PROTOBUF_NDEBUG_INLINE FloatList::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_FIELD
        value_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::rocal::tensorflow::FloatList,
            PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::FloatList, _impl_.value_)>()
        }
        #else
        value_ { visibility, arena }
        #endif
     {}

inline void FloatList::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
FloatList::~FloatList() {
  // @@protoc_insertion_point(destructor:rocal.tensorflow.FloatList)
  SharedDtor(*this);
}
inline void FloatList::SharedDtor(MessageLite& self) {
  FloatList& this_ = static_cast<FloatList&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL FloatList::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) FloatList(arena);
}
#ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
constexpr auto FloatList::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(FloatList),
                                            alignof(FloatList));
}
#else  // !PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
constexpr auto FloatList::InternalNewImpl_() {
  constexpr auto arena_bits = ::google::protobuf::internal::EncodePlacementArenaOffsets({
      PROTOBUF_FIELD_OFFSET(FloatList, _impl_.value_) +
          decltype(FloatList::_impl_.value_)::
              InternalGetArenaOffset(
                  ::google::protobuf::Message::internal_visibility()),
  });
  if (arena_bits.has_value()) {
    return ::google::protobuf::internal::MessageCreator::ZeroInit(
        sizeof(FloatList), alignof(FloatList), *arena_bits);
  } else {
    return ::google::protobuf::internal::MessageCreator(&FloatList::PlacementNew_,
                                 sizeof(FloatList),
                                 alignof(FloatList));
  }
}
#endif
constexpr auto FloatList::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_FloatList_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &FloatList::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<FloatList>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &FloatList::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<FloatList>(), &FloatList::ByteSizeLong,
              &FloatList::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(FloatList, _impl_._cached_size_),
          false,
      },
      &FloatList::kDescriptorMethods,
      &descriptor_table_feature_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull FloatList_class_data_ =
        FloatList::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
FloatList::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&FloatList_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(FloatList_class_data_.tc_table);
  return FloatList_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<0, 1, 0, 0, 2>
FloatList::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(FloatList, _impl_._has_bits_),
    0, // no _extensions_
    1, 0,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967294,  // skipmap
    offsetof(decltype(_table_), field_entries),
    1,  // num_field_entries
    0,  // num_aux_entries
    offsetof(decltype(_table_), field_names),  // no aux_entries
    FloatList_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::rocal::tensorflow::FloatList>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    // repeated float value = 1 [packed = true];
    {::_pbi::TcParser::FastF32P1,
     {10, 0, 0,
      PROTOBUF_FIELD_OFFSET(FloatList, _impl_.value_)}},
  }}, {{
    65535, 65535
  }}, {{
    // repeated float value = 1 [packed = true];
    {PROTOBUF_FIELD_OFFSET(FloatList, _impl_.value_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedFloat)},
  }},
  // no aux_entries
  {{
  }},
};
PROTOBUF_NOINLINE void FloatList::Clear() {
// @@protoc_insertion_point(message_clear_start:rocal.tensorflow.FloatList)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
    _impl_.value_.Clear();
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL FloatList::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const FloatList& this_ = static_cast<const FloatList&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL FloatList::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const FloatList& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:rocal.tensorflow.FloatList)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // repeated float value = 1 [packed = true];
  if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
    if (this_._internal_value_size() > 0) {
      target = stream->WriteFixedPacked(1, this_._internal_value(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:rocal.tensorflow.FloatList)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t FloatList::ByteSizeLong(const MessageLite& base) {
  const FloatList& this_ = static_cast<const FloatList&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t FloatList::ByteSizeLong() const {
  const FloatList& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:rocal.tensorflow.FloatList)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
   {
    // repeated float value = 1 [packed = true];
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
      ::size_t data_size = ::size_t{4} *
          ::_pbi::FromIntSize(this_._internal_value_size());
      ::size_t tag_size = data_size == 0
          ? 0
          : 1 + ::_pbi::WireFormatLite::Int32Size(
                              static_cast<::int32_t>(data_size));
      total_size += tag_size + data_size;
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void FloatList::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<FloatList*>(&to_msg);
  auto& from = static_cast<const FloatList&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:rocal.tensorflow.FloatList)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
    _this->_internal_mutable_value()->MergeFrom(from._internal_value());
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void FloatList::CopyFrom(const FloatList& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:rocal.tensorflow.FloatList)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void FloatList::InternalSwap(FloatList* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.value_.InternalSwap(&other->_impl_.value_);
}

::google::protobuf::Metadata FloatList::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Int64List::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Int64List>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Int64List, _impl_._has_bits_);
};

Int64List::Int64List(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Int64List_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:rocal.tensorflow.Int64List)
}
PROTOBUF_NDEBUG_INLINE Int64List::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::rocal::tensorflow::Int64List& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_FIELD
        value_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::rocal::tensorflow::Int64List,
            PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::Int64List, _impl_.value_)>()
        , from.value_}
        #else
        value_ { visibility, arena, from.value_ }
        #endif
        ,
        _value_cached_byte_size_{0} {}

Int64List::Int64List(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Int64List& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Int64List_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Int64List* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:rocal.tensorflow.Int64List)
}
PROTOBUF_NDEBUG_INLINE Int64List::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_FIELD
        value_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::rocal::tensorflow::Int64List,
            PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::Int64List, _impl_.value_)>()
        }
        #else
        value_ { visibility, arena }
        #endif
        ,
        _value_cached_byte_size_{0} {}

inline void Int64List::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
Int64List::~Int64List() {
  // @@protoc_insertion_point(destructor:rocal.tensorflow.Int64List)
  SharedDtor(*this);
}
inline void Int64List::SharedDtor(MessageLite& self) {
  Int64List& this_ = static_cast<Int64List&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Int64List::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Int64List(arena);
}
#ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
constexpr auto Int64List::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Int64List),
                                            alignof(Int64List));
}
#else  // !PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
constexpr auto Int64List::InternalNewImpl_() {
  constexpr auto arena_bits = ::google::protobuf::internal::EncodePlacementArenaOffsets({
      PROTOBUF_FIELD_OFFSET(Int64List, _impl_.value_) +
          decltype(Int64List::_impl_.value_)::
              InternalGetArenaOffset(
                  ::google::protobuf::Message::internal_visibility()),
  });
  if (arena_bits.has_value()) {
    return ::google::protobuf::internal::MessageCreator::ZeroInit(
        sizeof(Int64List), alignof(Int64List), *arena_bits);
  } else {
    return ::google::protobuf::internal::MessageCreator(&Int64List::PlacementNew_,
                                 sizeof(Int64List),
                                 alignof(Int64List));
  }
}
#endif
constexpr auto Int64List::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Int64List_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Int64List::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Int64List>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Int64List::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Int64List>(), &Int64List::ByteSizeLong,
              &Int64List::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Int64List, _impl_._cached_size_),
          false,
      },
      &Int64List::kDescriptorMethods,
      &descriptor_table_feature_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Int64List_class_data_ =
        Int64List::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Int64List::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Int64List_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Int64List_class_data_.tc_table);
  return Int64List_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<0, 1, 0, 0, 2>
Int64List::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Int64List, _impl_._has_bits_),
    0, // no _extensions_
    1, 0,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967294,  // skipmap
    offsetof(decltype(_table_), field_entries),
    1,  // num_field_entries
    0,  // num_aux_entries
    offsetof(decltype(_table_), field_names),  // no aux_entries
    Int64List_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::rocal::tensorflow::Int64List>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    // repeated int64 value = 1 [packed = true];
    {::_pbi::TcParser::FastV64P1,
     {10, 0, 0,
      PROTOBUF_FIELD_OFFSET(Int64List, _impl_.value_)}},
  }}, {{
    65535, 65535
  }}, {{
    // repeated int64 value = 1 [packed = true];
    {PROTOBUF_FIELD_OFFSET(Int64List, _impl_.value_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedInt64)},
  }},
  // no aux_entries
  {{
  }},
};
PROTOBUF_NOINLINE void Int64List::Clear() {
// @@protoc_insertion_point(message_clear_start:rocal.tensorflow.Int64List)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
    _impl_.value_.Clear();
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Int64List::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Int64List& this_ = static_cast<const Int64List&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Int64List::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Int64List& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:rocal.tensorflow.Int64List)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // repeated int64 value = 1 [packed = true];
  if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
    {
      int byte_size = this_._impl_._value_cached_byte_size_.Get();
      if (byte_size > 0) {
        target = stream->WriteInt64Packed(
            1, this_._internal_value(), byte_size, target);
      }
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:rocal.tensorflow.Int64List)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Int64List::ByteSizeLong(const MessageLite& base) {
  const Int64List& this_ = static_cast<const Int64List&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Int64List::ByteSizeLong() const {
  const Int64List& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:rocal.tensorflow.Int64List)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
   {
    // repeated int64 value = 1 [packed = true];
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
      total_size +=
          ::_pbi::WireFormatLite::Int64SizeWithPackedTagSize(
              this_._internal_value(), 1,
              this_._impl_._value_cached_byte_size_);
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Int64List::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Int64List*>(&to_msg);
  auto& from = static_cast<const Int64List&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:rocal.tensorflow.Int64List)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
    _this->_internal_mutable_value()->MergeFrom(from._internal_value());
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Int64List::CopyFrom(const Int64List& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:rocal.tensorflow.Int64List)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Int64List::InternalSwap(Int64List* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.value_.InternalSwap(&other->_impl_.value_);
}

::google::protobuf::Metadata Int64List::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Feature::_Internal {
 public:
  static constexpr ::int32_t kOneofCaseOffset =
      PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::Feature, _impl_._oneof_case_);
};

void Feature::set_allocated_bytes_list(::rocal::tensorflow::BytesList* PROTOBUF_NULLABLE bytes_list) {
  ::google::protobuf::Arena* message_arena = GetArena();
  clear_kind();
  if (bytes_list) {
    ::google::protobuf::Arena* submessage_arena = bytes_list->GetArena();
    if (message_arena != submessage_arena) {
      bytes_list = ::google::protobuf::internal::GetOwnedMessage(message_arena, bytes_list, submessage_arena);
    }
    set_has_bytes_list();
    _impl_.kind_.bytes_list_ = bytes_list;
  }
  // @@protoc_insertion_point(field_set_allocated:rocal.tensorflow.Feature.bytes_list)
}
void Feature::set_allocated_float_list(::rocal::tensorflow::FloatList* PROTOBUF_NULLABLE float_list) {
  ::google::protobuf::Arena* message_arena = GetArena();
  clear_kind();
  if (float_list) {
    ::google::protobuf::Arena* submessage_arena = float_list->GetArena();
    if (message_arena != submessage_arena) {
      float_list = ::google::protobuf::internal::GetOwnedMessage(message_arena, float_list, submessage_arena);
    }
    set_has_float_list();
    _impl_.kind_.float_list_ = float_list;
  }
  // @@protoc_insertion_point(field_set_allocated:rocal.tensorflow.Feature.float_list)
}
void Feature::set_allocated_int64_list(::rocal::tensorflow::Int64List* PROTOBUF_NULLABLE int64_list) {
  ::google::protobuf::Arena* message_arena = GetArena();
  clear_kind();
  if (int64_list) {
    ::google::protobuf::Arena* submessage_arena = int64_list->GetArena();
    if (message_arena != submessage_arena) {
      int64_list = ::google::protobuf::internal::GetOwnedMessage(message_arena, int64_list, submessage_arena);
    }
    set_has_int64_list();
    _impl_.kind_.int64_list_ = int64_list;
  }
  // @@protoc_insertion_point(field_set_allocated:rocal.tensorflow.Feature.int64_list)
}
Feature::Feature(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Feature_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:rocal.tensorflow.Feature)
}
PROTOBUF_NDEBUG_INLINE Feature::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::rocal::tensorflow::Feature& from_msg)
      : kind_{},
        _cached_size_{0},
        _oneof_case_{from._oneof_case_[0]} {}

Feature::Feature(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Feature& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Feature_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Feature* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  switch (kind_case()) {
    case KIND_NOT_SET:
      break;
      case kBytesList:
        _impl_.kind_.bytes_list_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.kind_.bytes_list_);
        break;
      case kFloatList:
        _impl_.kind_.float_list_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.kind_.float_list_);
        break;
      case kInt64List:
        _impl_.kind_.int64_list_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.kind_.int64_list_);
        break;
  }

  // @@protoc_insertion_point(copy_constructor:rocal.tensorflow.Feature)
}
PROTOBUF_NDEBUG_INLINE Feature::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : kind_{},
        _cached_size_{0},
        _oneof_case_{} {}

inline void Feature::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
Feature::~Feature() {
  // @@protoc_insertion_point(destructor:rocal.tensorflow.Feature)
  SharedDtor(*this);
}
inline void Feature::SharedDtor(MessageLite& self) {
  Feature& this_ = static_cast<Feature&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  if (this_.has_kind()) {
    this_.clear_kind();
  }
  this_._impl_.~Impl_();
}

void Feature::clear_kind() {
// @@protoc_insertion_point(one_of_clear_start:rocal.tensorflow.Feature)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  switch (kind_case()) {
    case kBytesList: {
      if (GetArena() == nullptr) {
        delete _impl_.kind_.bytes_list_;
      } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
        ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.kind_.bytes_list_);
      }
      break;
    }
    case kFloatList: {
      if (GetArena() == nullptr) {
        delete _impl_.kind_.float_list_;
      } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
        ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.kind_.float_list_);
      }
      break;
    }
    case kInt64List: {
      if (GetArena() == nullptr) {
        delete _impl_.kind_.int64_list_;
      } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
        ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.kind_.int64_list_);
      }
      break;
    }
    case KIND_NOT_SET: {
      break;
    }
  }
  _impl_._oneof_case_[0] = KIND_NOT_SET;
}


inline void* PROTOBUF_NONNULL Feature::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Feature(arena);
}
constexpr auto Feature::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(Feature),
                                            alignof(Feature));
}
constexpr auto Feature::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Feature_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Feature::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Feature>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Feature::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Feature>(), &Feature::ByteSizeLong,
              &Feature::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Feature, _impl_._cached_size_),
          false,
      },
      &Feature::kDescriptorMethods,
      &descriptor_table_feature_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Feature_class_data_ =
        Feature::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Feature::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Feature_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Feature_class_data_.tc_table);
  return Feature_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<0, 3, 3, 0, 2>
Feature::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Feature,
                          _impl_._cached_size_),  // no hasbits
    0, // no _extensions_
    3, 0,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967288,  // skipmap
    offsetof(decltype(_table_), field_entries),
    3,  // num_field_entries
    3,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Feature_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::rocal::tensorflow::Feature>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
  }}, {{
    65535, 65535
  }}, {{
    // .rocal.tensorflow.BytesList bytes_list = 1;
    {PROTOBUF_FIELD_OFFSET(Feature, _impl_.kind_.bytes_list_), _Internal::kOneofCaseOffset + 0, 0, (0 | ::_fl::kFcOneof | ::_fl::kMessage | ::_fl::kTvTable)},
    // .rocal.tensorflow.FloatList float_list = 2;
    {PROTOBUF_FIELD_OFFSET(Feature, _impl_.kind_.float_list_), _Internal::kOneofCaseOffset + 0, 1, (0 | ::_fl::kFcOneof | ::_fl::kMessage | ::_fl::kTvTable)},
    // .rocal.tensorflow.Int64List int64_list = 3;
    {PROTOBUF_FIELD_OFFSET(Feature, _impl_.kind_.int64_list_), _Internal::kOneofCaseOffset + 0, 2, (0 | ::_fl::kFcOneof | ::_fl::kMessage | ::_fl::kTvTable)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::rocal::tensorflow::BytesList>()},
      {::_pbi::TcParser::GetTable<::rocal::tensorflow::FloatList>()},
      {::_pbi::TcParser::GetTable<::rocal::tensorflow::Int64List>()},
  }},
  {{
  }},
};
PROTOBUF_NOINLINE void Feature::Clear() {
// @@protoc_insertion_point(message_clear_start:rocal.tensorflow.Feature)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  clear_kind();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Feature::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Feature& this_ = static_cast<const Feature&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Feature::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Feature& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:rocal.tensorflow.Feature)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  switch (this_.kind_case()) {
    case kBytesList: {
      target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
          1, *this_._impl_.kind_.bytes_list_, this_._impl_.kind_.bytes_list_->GetCachedSize(), target,
          stream);
      break;
    }
    case kFloatList: {
      target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
          2, *this_._impl_.kind_.float_list_, this_._impl_.kind_.float_list_->GetCachedSize(), target,
          stream);
      break;
    }
    case kInt64List: {
      target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
          3, *this_._impl_.kind_.int64_list_, this_._impl_.kind_.int64_list_->GetCachedSize(), target,
          stream);
      break;
    }
    default:
      break;
  }
  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:rocal.tensorflow.Feature)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Feature::ByteSizeLong(const MessageLite& base) {
  const Feature& this_ = static_cast<const Feature&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Feature::ByteSizeLong() const {
  const Feature& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:rocal.tensorflow.Feature)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  switch (this_.kind_case()) {
    // .rocal.tensorflow.BytesList bytes_list = 1;
    case kBytesList: {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.kind_.bytes_list_);
      break;
    }
    // .rocal.tensorflow.FloatList float_list = 2;
    case kFloatList: {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.kind_.float_list_);
      break;
    }
    // .rocal.tensorflow.Int64List int64_list = 3;
    case kInt64List: {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.kind_.int64_list_);
      break;
    }
    case KIND_NOT_SET: {
      break;
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Feature::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Feature*>(&to_msg);
  auto& from = static_cast<const Feature&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:rocal.tensorflow.Feature)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  if (const uint32_t oneof_from_case =
          from._impl_._oneof_case_[0]) {
    const uint32_t oneof_to_case = _this->_impl_._oneof_case_[0];
    const bool oneof_needs_init = oneof_to_case != oneof_from_case;
    if (oneof_needs_init) {
      if (oneof_to_case != 0) {
        _this->clear_kind();
      }
      _this->_impl_._oneof_case_[0] = oneof_from_case;
    }

    switch (oneof_from_case) {
      case kBytesList: {
        if (oneof_needs_init) {
          _this->_impl_.kind_.bytes_list_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.kind_.bytes_list_);
        } else {
          _this->_impl_.kind_.bytes_list_->MergeFrom(*from._impl_.kind_.bytes_list_);
        }
        break;
      }
      case kFloatList: {
        if (oneof_needs_init) {
          _this->_impl_.kind_.float_list_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.kind_.float_list_);
        } else {
          _this->_impl_.kind_.float_list_->MergeFrom(*from._impl_.kind_.float_list_);
        }
        break;
      }
      case kInt64List: {
        if (oneof_needs_init) {
          _this->_impl_.kind_.int64_list_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.kind_.int64_list_);
        } else {
          _this->_impl_.kind_.int64_list_->MergeFrom(*from._impl_.kind_.int64_list_);
        }
        break;
      }
      case KIND_NOT_SET:
        break;
    }
  }
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Feature::CopyFrom(const Feature& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:rocal.tensorflow.Feature)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Feature::InternalSwap(Feature* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_.kind_, other->_impl_.kind_);
  swap(_impl_._oneof_case_[0], other->_impl_._oneof_case_[0]);
}

::google::protobuf::Metadata Feature::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

#if defined(PROTOBUF_CUSTOM_VTABLE)
Features_FeatureEntry_DoNotUse::Features_FeatureEntry_DoNotUse()
    : SuperType(Features_FeatureEntry_DoNotUse_class_data_.base()) {}
Features_FeatureEntry_DoNotUse::Features_FeatureEntry_DoNotUse(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
    : SuperType(arena, Features_FeatureEntry_DoNotUse_class_data_.base()) {}
#else   // PROTOBUF_CUSTOM_VTABLE
Features_FeatureEntry_DoNotUse::Features_FeatureEntry_DoNotUse() : SuperType() {}
Features_FeatureEntry_DoNotUse::Features_FeatureEntry_DoNotUse(::google::protobuf::Arena* PROTOBUF_NULLABLE arena) : SuperType(arena) {}
#endif  // PROTOBUF_CUSTOM_VTABLE
inline void* PROTOBUF_NONNULL Features_FeatureEntry_DoNotUse::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Features_FeatureEntry_DoNotUse(arena);
}
constexpr auto Features_FeatureEntry_DoNotUse::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Features_FeatureEntry_DoNotUse),
                                            alignof(Features_FeatureEntry_DoNotUse));
}
constexpr auto Features_FeatureEntry_DoNotUse::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Features_FeatureEntry_DoNotUse_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Features_FeatureEntry_DoNotUse::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Features_FeatureEntry_DoNotUse>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Features_FeatureEntry_DoNotUse::SharedDtor,
          static_cast<void (::google::protobuf::MessageLite::*)()>(&Features_FeatureEntry_DoNotUse::ClearImpl),
              ::google::protobuf::Message::ByteSizeLongImpl, ::google::protobuf::Message::_InternalSerializeImpl
              ,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Features_FeatureEntry_DoNotUse, _impl_._cached_size_),
          false,
      },
      &Features_FeatureEntry_DoNotUse::kDescriptorMethods,
      &descriptor_table_feature_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Features_FeatureEntry_DoNotUse_class_data_ =
        Features_FeatureEntry_DoNotUse::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Features_FeatureEntry_DoNotUse::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Features_FeatureEntry_DoNotUse_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Features_FeatureEntry_DoNotUse_class_data_.tc_table);
  return Features_FeatureEntry_DoNotUse_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<1, 2, 1, 50, 2>
Features_FeatureEntry_DoNotUse::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Features_FeatureEntry_DoNotUse, _impl_._has_bits_),
    0, // no _extensions_
    2, 8,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967292,  // skipmap
    offsetof(decltype(_table_), field_entries),
    2,  // num_field_entries
    1,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Features_FeatureEntry_DoNotUse_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::DiscardEverythingFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::rocal::tensorflow::Features_FeatureEntry_DoNotUse>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    // .rocal.tensorflow.Feature value = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 1, 0,
      PROTOBUF_FIELD_OFFSET(Features_FeatureEntry_DoNotUse, _impl_.value_)}},
    // string key = 1;
    {::_pbi::TcParser::FastUS1,
     {10, 0, 0,
      PROTOBUF_FIELD_OFFSET(Features_FeatureEntry_DoNotUse, _impl_.key_)}},
  }}, {{
    65535, 65535
  }}, {{
    // string key = 1;
    {PROTOBUF_FIELD_OFFSET(Features_FeatureEntry_DoNotUse, _impl_.key_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // .rocal.tensorflow.Feature value = 2;
    {PROTOBUF_FIELD_OFFSET(Features_FeatureEntry_DoNotUse, _impl_.value_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::rocal::tensorflow::Feature>()},
  }},
  {{
    "\46\3\0\0\0\0\0\0"
    "rocal.tensorflow.Features.FeatureEntry"
    "key"
  }},
};
// ===================================================================

class Features::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Features>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Features, _impl_._has_bits_);
};

Features::Features(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Features_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:rocal.tensorflow.Features)
}
PROTOBUF_NDEBUG_INLINE Features::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::rocal::tensorflow::Features& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_MAP_FIELD
        feature_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::rocal::tensorflow::Features,
            PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::Features, _impl_.feature_)>()
        , from.feature_}
        #else
        feature_ { visibility, arena, from.feature_ }
        #endif
     {}

Features::Features(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Features& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Features_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Features* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:rocal.tensorflow.Features)
}
PROTOBUF_NDEBUG_INLINE Features::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_MAP_FIELD
        feature_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::rocal::tensorflow::Features,
            PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::Features, _impl_.feature_)>()
        }
        #else
        feature_ { visibility, arena }
        #endif
     {}

inline void Features::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
Features::~Features() {
  // @@protoc_insertion_point(destructor:rocal.tensorflow.Features)
  SharedDtor(*this);
}
inline void Features::SharedDtor(MessageLite& self) {
  Features& this_ = static_cast<Features&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Features::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Features(arena);
}
#ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
constexpr auto Features::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Features),
                                            alignof(Features));
}
#else  // !PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
constexpr auto Features::InternalNewImpl_() {
  constexpr auto arena_bits = ::google::protobuf::internal::EncodePlacementArenaOffsets({
      PROTOBUF_FIELD_OFFSET(Features, _impl_.feature_) +
          decltype(Features::_impl_.feature_)::
              InternalGetArenaOffset(
                  ::google::protobuf::Message::internal_visibility()),
  });
  if (arena_bits.has_value()) {
    return ::google::protobuf::internal::MessageCreator::CopyInit(
        sizeof(Features), alignof(Features), *arena_bits);
  } else {
    return ::google::protobuf::internal::MessageCreator(&Features::PlacementNew_,
                                 sizeof(Features),
                                 alignof(Features));
  }
}
#endif
constexpr auto Features::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Features_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Features::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Features>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Features::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Features>(), &Features::ByteSizeLong,
              &Features::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Features, _impl_._cached_size_),
          false,
      },
      &Features::kDescriptorMethods,
      &descriptor_table_feature_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Features_class_data_ =
        Features::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Features::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Features_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Features_class_data_.tc_table);
  return Features_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<0, 1, 2, 41, 2>
Features::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Features, _impl_._has_bits_),
    0, // no _extensions_
    1, 0,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967294,  // skipmap
    offsetof(decltype(_table_), field_entries),
    1,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Features_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::rocal::tensorflow::Features>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
  }}, {{
    65535, 65535
  }}, {{
    // map<string, .rocal.tensorflow.Feature> feature = 1;
    {PROTOBUF_FIELD_OFFSET(Features, _impl_.feature_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kMap)},
  }},
  {{
      {::_pbi::TcParser::GetMapAuxInfo(
          1, 0, 9, 11, 0)},
      {::_pbi::TcParser::GetTable<::rocal::tensorflow::Feature>()},
  }},
  {{
    "\31\7\0\0\0\0\0\0"
    "rocal.tensorflow.Features"
    "feature"
  }},
};
PROTOBUF_NOINLINE void Features::Clear() {
// @@protoc_insertion_point(message_clear_start:rocal.tensorflow.Features)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
    _impl_.feature_.Clear();
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Features::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Features& this_ = static_cast<const Features&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Features::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Features& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:rocal.tensorflow.Features)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // map<string, .rocal.tensorflow.Feature> feature = 1;
  if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_feature().empty()) {
      using MapType = ::google::protobuf::Map<::std::string, ::rocal::tensorflow::Feature>;
      using WireHelper = _pbi::MapEntryFuncs<::std::string, ::rocal::tensorflow::Feature,
                                     _pbi::WireFormatLite::TYPE_STRING,
                                     _pbi::WireFormatLite::TYPE_MESSAGE>;
      const auto& field = this_._internal_feature();

      if (stream->IsSerializationDeterministic() && field.size() > 1) {
        for (const auto& entry : ::google::protobuf::internal::MapSorterPtr<MapType>(field)) {
          target = WireHelper::InternalSerialize(
              1, entry.first, entry.second, target, stream);
          ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
              entry.first.data(), static_cast<int>(entry.first.length()),
 ::google::protobuf::internal::WireFormatLite::SERIALIZE, "rocal.tensorflow.Features.feature");
        }
      } else {
        for (const auto& entry : field) {
          target = WireHelper::InternalSerialize(
              1, entry.first, entry.second, target, stream);
          ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
              entry.first.data(), static_cast<int>(entry.first.length()),
 ::google::protobuf::internal::WireFormatLite::SERIALIZE, "rocal.tensorflow.Features.feature");
        }
      }
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:rocal.tensorflow.Features)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Features::ByteSizeLong(const MessageLite& base) {
  const Features& this_ = static_cast<const Features&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Features::ByteSizeLong() const {
  const Features& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:rocal.tensorflow.Features)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
   {
    // map<string, .rocal.tensorflow.Feature> feature = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
      total_size +=
          1 * ::google::protobuf::internal::FromIntSize(this_._internal_feature_size());
      for (const auto& entry : this_._internal_feature()) {
        total_size += _pbi::MapEntryFuncs<::std::string, ::rocal::tensorflow::Feature,
                                       _pbi::WireFormatLite::TYPE_STRING,
                                       _pbi::WireFormatLite::TYPE_MESSAGE>::ByteSizeLong(entry.first, entry.second);
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Features::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Features*>(&to_msg);
  auto& from = static_cast<const Features&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:rocal.tensorflow.Features)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
    _this->_impl_.feature_.MergeFrom(from._impl_.feature_);
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Features::CopyFrom(const Features& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:rocal.tensorflow.Features)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Features::InternalSwap(Features* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.feature_.InternalSwap(&other->_impl_.feature_);
}

::google::protobuf::Metadata Features::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class FeatureList::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<FeatureList>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(FeatureList, _impl_._has_bits_);
};

FeatureList::FeatureList(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, FeatureList_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:rocal.tensorflow.FeatureList)
}
PROTOBUF_NDEBUG_INLINE FeatureList::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::rocal::tensorflow::FeatureList& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
        feature_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::rocal::tensorflow::FeatureList,
            PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::FeatureList, _impl_.feature_)>()
        , from.feature_}
        #else
        feature_ { visibility, arena, from.feature_ }
        #endif
     {}

FeatureList::FeatureList(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const FeatureList& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, FeatureList_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  FeatureList* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:rocal.tensorflow.FeatureList)
}
PROTOBUF_NDEBUG_INLINE FeatureList::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
        feature_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::rocal::tensorflow::FeatureList,
            PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::FeatureList, _impl_.feature_)>()
        }
        #else
        feature_ { visibility, arena }
        #endif
     {}

inline void FeatureList::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
FeatureList::~FeatureList() {
  // @@protoc_insertion_point(destructor:rocal.tensorflow.FeatureList)
  SharedDtor(*this);
}
inline void FeatureList::SharedDtor(MessageLite& self) {
  FeatureList& this_ = static_cast<FeatureList&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL FeatureList::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) FeatureList(arena);
}
#ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
constexpr auto FeatureList::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(FeatureList),
                                            alignof(FeatureList));
}
#else  // !PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
constexpr auto FeatureList::InternalNewImpl_() {
  constexpr auto arena_bits = ::google::protobuf::internal::EncodePlacementArenaOffsets({
      PROTOBUF_FIELD_OFFSET(FeatureList, _impl_.feature_) +
          decltype(FeatureList::_impl_.feature_)::
              InternalGetArenaOffset(
                  ::google::protobuf::Message::internal_visibility()),
  });
  if (arena_bits.has_value()) {
    return ::google::protobuf::internal::MessageCreator::ZeroInit(
        sizeof(FeatureList), alignof(FeatureList), *arena_bits);
  } else {
    return ::google::protobuf::internal::MessageCreator(&FeatureList::PlacementNew_,
                                 sizeof(FeatureList),
                                 alignof(FeatureList));
  }
}
#endif
constexpr auto FeatureList::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_FeatureList_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &FeatureList::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<FeatureList>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &FeatureList::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<FeatureList>(), &FeatureList::ByteSizeLong,
              &FeatureList::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(FeatureList, _impl_._cached_size_),
          false,
      },
      &FeatureList::kDescriptorMethods,
      &descriptor_table_feature_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull FeatureList_class_data_ =
        FeatureList::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
FeatureList::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&FeatureList_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(FeatureList_class_data_.tc_table);
  return FeatureList_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<0, 1, 1, 0, 2>
FeatureList::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(FeatureList, _impl_._has_bits_),
    0, // no _extensions_
    1, 0,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967294,  // skipmap
    offsetof(decltype(_table_), field_entries),
    1,  // num_field_entries
    1,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    FeatureList_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::rocal::tensorflow::FeatureList>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    // repeated .rocal.tensorflow.Feature feature = 1;
    {::_pbi::TcParser::FastMtR1,
     {10, 0, 0,
      PROTOBUF_FIELD_OFFSET(FeatureList, _impl_.feature_)}},
  }}, {{
    65535, 65535
  }}, {{
    // repeated .rocal.tensorflow.Feature feature = 1;
    {PROTOBUF_FIELD_OFFSET(FeatureList, _impl_.feature_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::rocal::tensorflow::Feature>()},
  }},
  {{
  }},
};
PROTOBUF_NOINLINE void FeatureList::Clear() {
// @@protoc_insertion_point(message_clear_start:rocal.tensorflow.FeatureList)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
    _impl_.feature_.Clear();
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL FeatureList::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const FeatureList& this_ = static_cast<const FeatureList&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL FeatureList::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const FeatureList& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:rocal.tensorflow.FeatureList)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // repeated .rocal.tensorflow.Feature feature = 1;
  if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_feature_size());
         i < n; i++) {
      const auto& repfield = this_._internal_feature().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              1, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:rocal.tensorflow.FeatureList)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t FeatureList::ByteSizeLong(const MessageLite& base) {
  const FeatureList& this_ = static_cast<const FeatureList&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t FeatureList::ByteSizeLong() const {
  const FeatureList& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:rocal.tensorflow.FeatureList)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
   {
    // repeated .rocal.tensorflow.Feature feature = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
      total_size += 1UL * this_._internal_feature_size();
      for (const auto& msg : this_._internal_feature()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void FeatureList::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<FeatureList*>(&to_msg);
  auto& from = static_cast<const FeatureList&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:rocal.tensorflow.FeatureList)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
    _this->_internal_mutable_feature()->InternalMergeFromWithArena(
        ::google::protobuf::MessageLite::internal_visibility(), arena,
        from._internal_feature());
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void FeatureList::CopyFrom(const FeatureList& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:rocal.tensorflow.FeatureList)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void FeatureList::InternalSwap(FeatureList* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.feature_.InternalSwap(&other->_impl_.feature_);
}

::google::protobuf::Metadata FeatureList::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

#if defined(PROTOBUF_CUSTOM_VTABLE)
FeatureLists_FeatureListEntry_DoNotUse::FeatureLists_FeatureListEntry_DoNotUse()
    : SuperType(FeatureLists_FeatureListEntry_DoNotUse_class_data_.base()) {}
FeatureLists_FeatureListEntry_DoNotUse::FeatureLists_FeatureListEntry_DoNotUse(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
    : SuperType(arena, FeatureLists_FeatureListEntry_DoNotUse_class_data_.base()) {}
#else   // PROTOBUF_CUSTOM_VTABLE
FeatureLists_FeatureListEntry_DoNotUse::FeatureLists_FeatureListEntry_DoNotUse() : SuperType() {}
FeatureLists_FeatureListEntry_DoNotUse::FeatureLists_FeatureListEntry_DoNotUse(::google::protobuf::Arena* PROTOBUF_NULLABLE arena) : SuperType(arena) {}
#endif  // PROTOBUF_CUSTOM_VTABLE
inline void* PROTOBUF_NONNULL FeatureLists_FeatureListEntry_DoNotUse::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) FeatureLists_FeatureListEntry_DoNotUse(arena);
}
constexpr auto FeatureLists_FeatureListEntry_DoNotUse::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(FeatureLists_FeatureListEntry_DoNotUse),
                                            alignof(FeatureLists_FeatureListEntry_DoNotUse));
}
constexpr auto FeatureLists_FeatureListEntry_DoNotUse::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_FeatureLists_FeatureListEntry_DoNotUse_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &FeatureLists_FeatureListEntry_DoNotUse::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<FeatureLists_FeatureListEntry_DoNotUse>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &FeatureLists_FeatureListEntry_DoNotUse::SharedDtor,
          static_cast<void (::google::protobuf::MessageLite::*)()>(&FeatureLists_FeatureListEntry_DoNotUse::ClearImpl),
              ::google::protobuf::Message::ByteSizeLongImpl, ::google::protobuf::Message::_InternalSerializeImpl
              ,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(FeatureLists_FeatureListEntry_DoNotUse, _impl_._cached_size_),
          false,
      },
      &FeatureLists_FeatureListEntry_DoNotUse::kDescriptorMethods,
      &descriptor_table_feature_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull FeatureLists_FeatureListEntry_DoNotUse_class_data_ =
        FeatureLists_FeatureListEntry_DoNotUse::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
FeatureLists_FeatureListEntry_DoNotUse::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&FeatureLists_FeatureListEntry_DoNotUse_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(FeatureLists_FeatureListEntry_DoNotUse_class_data_.tc_table);
  return FeatureLists_FeatureListEntry_DoNotUse_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<1, 2, 1, 58, 2>
FeatureLists_FeatureListEntry_DoNotUse::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(FeatureLists_FeatureListEntry_DoNotUse, _impl_._has_bits_),
    0, // no _extensions_
    2, 8,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967292,  // skipmap
    offsetof(decltype(_table_), field_entries),
    2,  // num_field_entries
    1,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    FeatureLists_FeatureListEntry_DoNotUse_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::DiscardEverythingFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::rocal::tensorflow::FeatureLists_FeatureListEntry_DoNotUse>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    // .rocal.tensorflow.FeatureList value = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 1, 0,
      PROTOBUF_FIELD_OFFSET(FeatureLists_FeatureListEntry_DoNotUse, _impl_.value_)}},
    // string key = 1;
    {::_pbi::TcParser::FastUS1,
     {10, 0, 0,
      PROTOBUF_FIELD_OFFSET(FeatureLists_FeatureListEntry_DoNotUse, _impl_.key_)}},
  }}, {{
    65535, 65535
  }}, {{
    // string key = 1;
    {PROTOBUF_FIELD_OFFSET(FeatureLists_FeatureListEntry_DoNotUse, _impl_.key_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // .rocal.tensorflow.FeatureList value = 2;
    {PROTOBUF_FIELD_OFFSET(FeatureLists_FeatureListEntry_DoNotUse, _impl_.value_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::rocal::tensorflow::FeatureList>()},
  }},
  {{
    "\56\3\0\0\0\0\0\0"
    "rocal.tensorflow.FeatureLists.FeatureListEntry"
    "key"
  }},
};
// ===================================================================

class FeatureLists::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<FeatureLists>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(FeatureLists, _impl_._has_bits_);
};

FeatureLists::FeatureLists(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, FeatureLists_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:rocal.tensorflow.FeatureLists)
}
PROTOBUF_NDEBUG_INLINE FeatureLists::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::rocal::tensorflow::FeatureLists& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_MAP_FIELD
        feature_list_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::rocal::tensorflow::FeatureLists,
            PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::FeatureLists, _impl_.feature_list_)>()
        , from.feature_list_}
        #else
        feature_list_ { visibility, arena, from.feature_list_ }
        #endif
     {}

FeatureLists::FeatureLists(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const FeatureLists& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, FeatureLists_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  FeatureLists* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:rocal.tensorflow.FeatureLists)
}
PROTOBUF_NDEBUG_INLINE FeatureLists::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_MAP_FIELD
        feature_list_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::rocal::tensorflow::FeatureLists,
            PROTOBUF_FIELD_OFFSET(::rocal::tensorflow::FeatureLists, _impl_.feature_list_)>()
        }
        #else
        feature_list_ { visibility, arena }
        #endif
     {}

inline void FeatureLists::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
FeatureLists::~FeatureLists() {
  // @@protoc_insertion_point(destructor:rocal.tensorflow.FeatureLists)
  SharedDtor(*this);
}
inline void FeatureLists::SharedDtor(MessageLite& self) {
  FeatureLists& this_ = static_cast<FeatureLists&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL FeatureLists::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) FeatureLists(arena);
}
#ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
constexpr auto FeatureLists::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(FeatureLists),
                                            alignof(FeatureLists));
}
#else  // !PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
constexpr auto FeatureLists::InternalNewImpl_() {
  constexpr auto arena_bits = ::google::protobuf::internal::EncodePlacementArenaOffsets({
      PROTOBUF_FIELD_OFFSET(FeatureLists, _impl_.feature_list_) +
          decltype(FeatureLists::_impl_.feature_list_)::
              InternalGetArenaOffset(
                  ::google::protobuf::Message::internal_visibility()),
  });
  if (arena_bits.has_value()) {
    return ::google::protobuf::internal::MessageCreator::CopyInit(
        sizeof(FeatureLists), alignof(FeatureLists), *arena_bits);
  } else {
    return ::google::protobuf::internal::MessageCreator(&FeatureLists::PlacementNew_,
                                 sizeof(FeatureLists),
                                 alignof(FeatureLists));
  }
}
#endif
constexpr auto FeatureLists::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_FeatureLists_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &FeatureLists::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<FeatureLists>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &FeatureLists::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<FeatureLists>(), &FeatureLists::ByteSizeLong,
              &FeatureLists::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(FeatureLists, _impl_._cached_size_),
          false,
      },
      &FeatureLists::kDescriptorMethods,
      &descriptor_table_feature_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull FeatureLists_class_data_ =
        FeatureLists::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
FeatureLists::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&FeatureLists_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(FeatureLists_class_data_.tc_table);
  return FeatureLists_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<0, 1, 2, 50, 2>
FeatureLists::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(FeatureLists, _impl_._has_bits_),
    0, // no _extensions_
    1, 0,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967294,  // skipmap
    offsetof(decltype(_table_), field_entries),
    1,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    FeatureLists_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::rocal::tensorflow::FeatureLists>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
  }}, {{
    65535, 65535
  }}, {{
    // map<string, .rocal.tensorflow.FeatureList> feature_list = 1;
    {PROTOBUF_FIELD_OFFSET(FeatureLists, _impl_.feature_list_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kMap)},
  }},
  {{
      {::_pbi::TcParser::GetMapAuxInfo(
          1, 0, 9, 11, 0)},
      {::_pbi::TcParser::GetTable<::rocal::tensorflow::FeatureList>()},
  }},
  {{
    "\35\14\0\0\0\0\0\0"
    "rocal.tensorflow.FeatureLists"
    "feature_list"
  }},
};
PROTOBUF_NOINLINE void FeatureLists::Clear() {
// @@protoc_insertion_point(message_clear_start:rocal.tensorflow.FeatureLists)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
    _impl_.feature_list_.Clear();
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL FeatureLists::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const FeatureLists& this_ = static_cast<const FeatureLists&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL FeatureLists::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const FeatureLists& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:rocal.tensorflow.FeatureLists)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // map<string, .rocal.tensorflow.FeatureList> feature_list = 1;
  if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_feature_list().empty()) {
      using MapType = ::google::protobuf::Map<::std::string, ::rocal::tensorflow::FeatureList>;
      using WireHelper = _pbi::MapEntryFuncs<::std::string, ::rocal::tensorflow::FeatureList,
                                     _pbi::WireFormatLite::TYPE_STRING,
                                     _pbi::WireFormatLite::TYPE_MESSAGE>;
      const auto& field = this_._internal_feature_list();

      if (stream->IsSerializationDeterministic() && field.size() > 1) {
        for (const auto& entry : ::google::protobuf::internal::MapSorterPtr<MapType>(field)) {
          target = WireHelper::InternalSerialize(
              1, entry.first, entry.second, target, stream);
          ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
              entry.first.data(), static_cast<int>(entry.first.length()),
 ::google::protobuf::internal::WireFormatLite::SERIALIZE, "rocal.tensorflow.FeatureLists.feature_list");
        }
      } else {
        for (const auto& entry : field) {
          target = WireHelper::InternalSerialize(
              1, entry.first, entry.second, target, stream);
          ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
              entry.first.data(), static_cast<int>(entry.first.length()),
 ::google::protobuf::internal::WireFormatLite::SERIALIZE, "rocal.tensorflow.FeatureLists.feature_list");
        }
      }
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:rocal.tensorflow.FeatureLists)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t FeatureLists::ByteSizeLong(const MessageLite& base) {
  const FeatureLists& this_ = static_cast<const FeatureLists&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t FeatureLists::ByteSizeLong() const {
  const FeatureLists& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:rocal.tensorflow.FeatureLists)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
   {
    // map<string, .rocal.tensorflow.FeatureList> feature_list = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
      total_size +=
          1 * ::google::protobuf::internal::FromIntSize(this_._internal_feature_list_size());
      for (const auto& entry : this_._internal_feature_list()) {
        total_size += _pbi::MapEntryFuncs<::std::string, ::rocal::tensorflow::FeatureList,
                                       _pbi::WireFormatLite::TYPE_STRING,
                                       _pbi::WireFormatLite::TYPE_MESSAGE>::ByteSizeLong(entry.first, entry.second);
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void FeatureLists::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<FeatureLists*>(&to_msg);
  auto& from = static_cast<const FeatureLists&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:rocal.tensorflow.FeatureLists)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
    _this->_impl_.feature_list_.MergeFrom(from._impl_.feature_list_);
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void FeatureLists::CopyFrom(const FeatureLists& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:rocal.tensorflow.FeatureLists)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void FeatureLists::InternalSwap(FeatureLists* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.feature_list_.InternalSwap(&other->_impl_.feature_list_);
}

::google::protobuf::Metadata FeatureLists::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// @@protoc_insertion_point(namespace_scope)
}  // namespace tensorflow
}  // namespace rocal
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google
// @@protoc_insertion_point(global_scope)
PROTOBUF_ATTRIBUTE_INIT_PRIORITY2 static ::std::false_type
    _static_init2_ [[maybe_unused]] =
        (::_pbi::AddDescriptors(&descriptor_table_feature_2eproto),
         ::std::false_type{});
#include "google/protobuf/port_undef.inc"
